<?php

function drupalit_views_tables() {
  
  $tables['drupalit_votes'] = array(
    'name' => 'drupalit_votes',
    'join' => array(
      'left' => array(
        'table' => 'node',
        'field' => 'nid',
      ),
      'right' => array(
        'field' => 'nid',
      ),
    ),
    'fields' => array(
      'votes' => array(
        'name' => t('Drupalit: Total Votes'),
        'sortable' => true,
        'handler' => 'drupalit_views_handler_votes',
        'help' => t('Display total votes of the node.'),
      ),
      'daily_votes' => array(
        'name' => t('Drupalit: Daily Votes'),
        'sortable' => true,
        'handler' => 'drupalit_views_handler_daily_votes',
        'help' => t('Display daily votes of the node.'),
      ),
      'weekly_votes' => array(
        'name' => t('Drupalit: Weekly Votes'),
        'sortable' => true,
        'handler' => 'drupalit_views_handler_weekly_votes',
        'help' => t('Display weekly votes of the node.'),
      ),
      'monthly_votes' => array(
        'name' => t('Drupalit: Monthly Votes'),
        'sortable' => true,
        'handler' => 'drupalit_views_handler_monthly_votes',
        'help' => t('Display monthly votes of the node.'),
      ),
    ),
    'filters' => array(
      'nid' => array(
        'name' => t('Drupalit: Has drupalit votes'),
        'operator' => array('=' => t('Exists')),
        'list' => 'views_handler_operator_yesno',
        'list-type' => 'select',
        'handler' => '_drupalit_views_handler_votes_exist',
        'help' => t('Filter whether the node has drupalit votes or not.'),
      ),
    ),
    'sorts' => array(
      'votes' => array(
        'name' => t('Drupalit: Total Votes'),
        'field' => 'votes',
        'help' => t('Sort by drupalit total votes.'),
       ),
       'daily_votes' => array(
        'name' => t('Drupalit: Daily Votes'),
        'help' => t('Sort by drupalit daily votes.'),
        'field' => 'daily_votes',
       ),
       'weekly_votes' => array(
        'name' => t('Drupalit: Weekly Votes'),
        'help' => t('Sort by drupalit weekly votes.'),
        'field' => 'weekly_votes',
       ),
       'monthly_votes' => array(
        'name' => t('Drupalit: Monthly Votes'),
        'help' => t('Sort by drupalit daily votes.'),
        'field' => 'monthly_votes',
       ),
    ),
  );
  return $tables;
}

function _drupalit_query_handler_display($field, $fieldinfo, &$query) {
  $query->add_field('nid', 'node');
}

function drupalit_views_handler_votes($fieldinfo, $fielddata, $value, $data) {
  $sql = db_query("SELECT votes FROM {drupalit_votes} WHERE nid = %d", $data->nid);
  $result = db_fetch_object($sql);
  return $result->votes;
}

function drupalit_views_handler_daily_votes($fieldinfo, $fielddata, $value, $data) {
  $sql = db_query("SELECT daily_votes FROM {drupalit_votes} WHERE nid = %d", $data->nid);
  $result = db_fetch_object($sql);
  return $result->daily_votes;
}

function drupalit_views_handler_weekly_votes($fieldinfo, $fielddata, $value, $data) {
  $sql = db_query("SELECT weekly_votes FROM {drupalit_votes} WHERE nid = %d", $data->nid);
  $result = db_fetch_object($sql);
  return $result->weekly_votes;
}

function drupalit_views_handler_monthly_votes($fieldinfo, $fielddata, $value, $data) {
  $sql = db_query("SELECT monthly_votes FROM {drupalit_votes} WHERE nid = %d", $data->nid);
  $result = db_fetch_object($sql);
  return $result->monthly_votes;
}

function _drupalit_views_handler_votes_exist($op, $filter, $filterdata, &$query) {
  switch ($op) {
    case 'handler':
      $query->ensure_table('drupalit_votes');
      if ($filter['value']) {
        $query->set_distinct();
        $table_data = _views_get_tables();
	$joins = array('type' => 'inner');
	$joins = array_merge($joins, $table_data['drupalit_votes']['join']);
        $query->joins['drupalit_votes'][1] = $joins;
      }
      else {
        $query->add_where('ISNULL(drupalit_votes.id)');
      }
  }
}